@@ -38,6 +38,8 @@ type TemplateOptions struct {
 	PostRendererArgs []string
 	// KubeVersion is the kube-version flag
 	KubeVersion string
+	// Propagate '--show-only` to helm template
+	ShowOnly []string
 }
 
 // NewTemplateOptions creates a new Apply
@@ -137,3 +139,8 @@ func (t *TemplateImpl) PostRendererArgs() []string {
 func (t *TemplateImpl) KubeVersion() string {
 	return t.TemplateOptions.KubeVersion
 }
+
+// ShowOnly returns the ShowOnly.
+func (t *TemplateImpl) ShowOnly() []string {
+	return t.TemplateOptions.ShowOnly
+}
